; bigtest.nsi
;
; This script attempts to test most of the functionality of the NSIS exehead.

;--------------------------------

SetCompressor lzma
SetCompress force
!ifdef HAVE_UPX
!packhdr tmp.dat "upx\upx -9 tmp.dat"
!endif

;--------------------------------

Name "MPDC"
Caption "MPD Commander"
Icon "mpdc.ico"
OutFile "mpdc.setup.exe"

SetDateSave on
SetDatablockOptimize on
CRCCheck on
SilentInstall normal
BGGradient 000000 800000 FFFFFF
InstallColors FF8080 000030
XPStyle on

InstallDir "$PROGRAMFILES\MPDC"

;CheckBitmap "..\Contrib\Graphics\Checks\classic-cross.bmp"

LicenseText "Please read the following license carefully:"
LicenseData "COPYING"

;--------------------------------

Page license
Page components
Page directory
Page instfiles

UninstPage uninstConfirm
UninstPage instfiles

;--------------------------------

!ifndef NOINSTTYPES ; only if not defined
  InstType "English"
  InstType "Nederlands"
  InstType "Deutsch"
  InstType "Franais"
  InstType "Espaol"
  InstType "Source only"
  ;InstType /NOCUSTOM
  ;InstType /COMPONENTSONLYONCUSTOM
!endif

AutoCloseWindow false
ShowInstDetails show

;--------------------------------

Section "" ; empty string makes it hidden, so would starting with -

  WriteRegStr HKLM SOFTWARE\MPDC "Install_Dir" "$INSTDIR"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\MPDC" "DisplayName" "MPD Commander (remove only)"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\MPDC" "UninstallString" '"$INSTDIR\mpdc-uninst.exe"'

  SetOutPath $INSTDIR
  WriteUninstaller "mpdc-uninst.exe"

SectionEnd


Section "Core binaries"
  SectionIn 1 2 3 4 5 RO

  CreateDirectory "$INSTDIR"
  SetOutPath $INSTDIR
  File /a "bin\qt-mtedu322.dll"
  File /a "bin\msvcrt.dll"
  File /a "bin\msvcp60.dll"

  SetOutPath $INSTDIR
  File /a "COPYING"

  CreateShortCut "$SMPROGRAMS\MPD Commander.lnk" "$INSTDIR\mpdc.exe" "" "" 0
SectionEnd

Section "English binaries"
  SectionIn 1 RO

  SetOutPath $INSTDIR
  File /a "bin\en\mpdc.exe"
SectionEnd

Section "Dutch binaries"
  SectionIn 2 RO

  SetOutPath $INSTDIR
  File /a "bin\nl\mpdc.exe"
SectionEnd

Section "German binaries"
  SectionIn 3 RO

  SetOutPath $INSTDIR
  File /a "bin\de\mpdc.exe"
SectionEnd

Section "French binaries"
  SectionIn 4 RO

  SetOutPath $INSTDIR
  File /a "bin\fr\mpdc.exe"
SectionEnd

Section "Spanish binaries"
  SectionIn 5 RO

  SetOutPath $INSTDIR
  File /a "bin\es\mpdc.exe"
SectionEnd

Section "Source code"
  SectionIn 6

  CreateDirectory "$INSTDIR\src\xpm"
  SetOutPath $INSTDIR\src
  File /a "src\*.*"
  SetOutPath $INSTDIR\src\xpm
  File /a "src\xpm\*.*"

  SetOutPath $INSTDIR
  File /a "configure"
  File /a "configure.bat"
  File /a "Makefile.gcc"
  File /a "Makefile.msc"
  File /a "configure.bat"
  File /a "mpdc.pro"
  File /a "mpdc.rc"
  File /a "mpdc.ico"
  File /a "todo.txt"
  File /a "installer.nsi"
  File /a "INSTALL"
SectionEnd

Section "Source documentation"
  SectionIn 6

  CreateDirectory "$INSTDIR\doc\html"
  SetOutPath $INSTDIR\doc\html
  File /a "doc\html\*.*"
  CreateShortCut "$INSTDIR\doc\index.html.lnk" "$INSTDIR\doc\html\index.html" "" "" 0
SectionEnd


; Uninstaller

UninstallText "This will uninstall MPD Commander. Hit next to continue."
UninstallIcon "mpdc.ico"

Section "Uninstall"

  DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\MPDC"
  Delete "$INSTDIR\qt-mtedu322.dll"
  Delete "$INSTDIR\msvcrt.dll"
  Delete "$INSTDIR\msvcp60.dll"
  Delete "$INSTDIR\COPYING"
  Delete "$INSTDIR\mpdc.exe"
  Delete "$SMPROGRAMS\MPD Commander.lnk"

  RMDir "$INSTDIR"

  IfFileExists "$INSTDIR" 0 NoErrorMsg
    MessageBox MB_OK "Note: $INSTDIR could not be removed!" IDOK 0 ; skipped if file doesn't exist
  NoErrorMsg:

SectionEnd
