#ifndef __CONFIGFILE__H
#define __CONFIGFILE__H

#include "mpdc.h"

// Class forwarding
#include <qmap.h>
#include <qstring.h>
#include <qstringlist.h>

class ConfigFile
{
public:
    typedef QMap<QString, QString> ConfigGroup;

public:
                                ConfigFile(const QString &fn);
                                ~ConfigFile();

  void                          setGroup(const QString &gname);                 //!< Sets the current 'directory' in the file.
  void                          writeEntry(const QString &key, const QString &value); //!< Write a string entry.
  void                          writeEncryptedEntry(const QString &key, const QString &value); //!< Write an encrypted string entry.
  void                          writeEntry(const QString &key, int num);        //!< Write a number entry.
  void                          writeEntry(const QString &key, bool b);         //!< Write a boolean entry.
  void                          writeEntry(const QString &key, const QStringList &lst, const QChar &sep); //!< Write a stringlist entry separated by sep.

  QString                       readEntry(const QString &key, const QString &deflt = QString::null); //!< Read a string entry.
  QString                       readEncryptedEntry(const QString &key, const QString &deflt = QString::null); //!< Read (and decrypt) a string entry.
  int                           readNumEntry(const QString &key, int deflt = -1 ); //!< Read a number entry.
  bool                          readBoolEntry(const QString &key, bool deflt = FALSE); //!< Read a boolean entry.
  QStringList                   readListEntry(const QString &key, const QChar &sep); //!< Read a stringlist of items separated by sep.

  void                          clearGroup();                                   //!< Clears the current 'directory' in the file.
  void                          deleteGroup();                                  //!< Deletes the current 'directory' in the file.
  status_t                      write(const QString &fn = QString::null);       //!< Write (commit) the file.

protected:
  void                          read();                                         //!< Read the file.
  void                          parse(const QString &line);                     //!< Parse a specific line.

private:
  QMap<QString, ConfigGroup>    groups;
  QMap<QString, ConfigGroup>::Iterator git;
  QString                       filename;
};

#endif
