#include <iostream>
#include <qpainter.h>

#include "gslider.h"

GSlider::GSlider(QWidget * parent)
        :QWidget(parent),
         pmStage(NULL),
         stageCount(0),
         currentStage(0),
         offset(0),
         hoffset(0),
         maximum(100),
         pressed(false)
{
}

void GSlider::setValue(int val)
{
  currentStage = val * stageCount / maximum;
  if (currentStage >= stageCount)
    currentStage = stageCount - 1;

  offset = val * (width() - pmButtonDown.width()) / maximum;
  if (offset >= width() - pmButtonDown.width())
    offset = width() - pmButtonDown.width() - 1;

  repaint(true);
}

void GSlider::setMax(int m)
{
  maximum = m;
}

int GSlider::value(void)
{
  return offset * maximum / (width() - pmButtonDown.width());
}

void GSlider::paintEvent(QPaintEvent *)
{
  QPainter painter(this);

  painter.drawPixmap(offset, hoffset, pressed ? pmButtonDown : pmButtonUp);
}

void GSlider::mouseMoveEvent(QMouseEvent *event)
{
  if (pressed)
  {
    offset = event->x() - pmButtonDown.width() / 2;
    if (offset > width() - pmButtonDown.width())
      offset = width() - pmButtonDown.width();
    if (offset < 0)
      offset = 0;

    currentStage = offset * stageCount / (width() - pmButtonDown.width());
    if (currentStage >= stageCount)
      currentStage = stageCount - 1;

    if (pmStage)
    #if QT_VERSION >= 300
      setErasePixmap(pmStage[currentStage]);
    #else
      setBackgroundPixmap(pmStage[currentStage]);
    #endif

    repaint(true);
    emit sliderMoved(offset * maximum / (width() - pmButtonDown.width()));
  }
}

void GSlider::mousePressEvent(QMouseEvent *event)
{
  offset = event->x() - pmButtonDown.width() / 2;
  if (offset > width() - pmButtonDown.width())
    offset = width() - pmButtonDown.width();
  if (offset < 0)
    offset = 0;

  currentStage = offset * stageCount / (width() - pmButtonDown.width());
  if (currentStage >= stageCount)
    currentStage = stageCount - 1;

  if (pmStage)
  #if QT_VERSION >= 300
    setErasePixmap(pmStage[currentStage]);
  #else
    setBackgroundPixmap(pmStage[currentStage]);
  #endif

  pressed = true;
  repaint(true);
  emit sliderPressed();
  emit sliderMoved(offset * maximum / (width() - pmButtonDown.width()));
}

void GSlider::mouseReleaseEvent(QMouseEvent *)
{
  pressed = false;
  repaint(true);
  emit sliderReleased();
}

void GSlider::wheelEvent(QWheelEvent *event)
{
  if (event->delta() > 0)
    offset -= 2;
  else
    offset += 2;

  if (offset > width() - pmButtonDown.width())
    offset = width() - pmButtonDown.width();
  if (offset < 0)
    offset = 0;

  currentStage = offset * stageCount / (width() - pmButtonDown.width());
  if (currentStage >= stageCount)
    currentStage = stageCount - 1;

  if (pmStage)
  #if QT_VERSION >= 300
    setErasePixmap(pmStage[currentStage]);
  #else
    setBackgroundPixmap(pmStage[currentStage]);
  #endif

  repaint(true);
  emit sliderMoved(offset * maximum / (width() - pmButtonDown.width()));
}
