#ifndef __MPDC_H
#define __MPDC_H

#include <iostream>
#include <qmessagebox.h>
#include <qstring.h>

//#define NDEBUG

#define __VERSION               "0.3 rc1"
#define __AUTHORS               "Copyright (c) 2004 by A.E. van Putten and A.J. Admiraal. Licensed under the GPL. Visit engineering.kabel.utwente.nl for more information."

#if defined(LANGUAGE_NL)
  #include "language.nl"
#elif defined(LANGUAGE_DE)
  #include "language.de"
#elif defined(LANGUAGE_FR)
  #include "language.fr"
#elif defined(LANGUAGE_ES)
  #include "language.es"
#else
  #include "language.en"
#endif

// The windows compiler doesn't use the C++ for scope
#ifdef _MSC_VER
  #define OLD_FOR_SCOPE_PATCH   if(true)
#else
  #define OLD_FOR_SCOPE_PATCH
#endif

typedef enum                    { T_OK = 0, T_WARNING = 1, T_ERROR = -1 } status_t;

#define test(expr,txt) if(expr)               \
  {                                           \
    QMessageBox mb ( "Error", txt, QMessageBox::Warning, QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton );       \
    mb.exec();                                \
    return;                                   \
  }

#define dbgConnect(sender,signal,receiver,slot) \
  if( !connect(sender,signal,receiver,slot ) ) std::cerr << __FILE__ << ":" << __LINE__ << " > " << "Slot not connected signal: " << #signal << " slot: " << #slot << std::endl;

#ifdef QT_NO_DEBUG
  #define debug(txt) ;
#else
  #define debug(txt) std::cout << __FILE__ << ":" << __LINE__ << " > " << txt << std::endl;
#endif

inline QString                  secToHMS(unsigned s)
{
  int sec = s % 60;
  int min = (s / 60) % 60;
  int hour = s / 3600;

  return( QString::number(hour) + ":" +
          ("0" + QString::number(min)).right(2) + ":" +
          ("0" + QString::number(sec)).right(2));
}

inline bool getSongArtist(QString filename, QString &song, QString &artist)
{
  QString name = "";

  for (int i=filename.length()-1; (i>=0) && (filename[i] != '/') && (filename[i] != '\\'); i--)
    name = filename[i] + name;

  while (((name[0] >= '0') && (name[0] <= '9')) || (name[0] == '.') || (name[0] == ' ') || (name[0] == '-'))
    name = name.right(name.length()-1);

  int dot = name.find('.', name.length()-7);
  if (dot >= 0)
    name = name.left(dot);

  int br1 = name.find('[');
  int br2 = name.find(']', br1);
  if ((br1 < br2) && (br1 >= 0))
  {
    artist = name.mid(br1+1, br2-br1-1).simplifyWhiteSpace();
    song = name.left(br1).simplifyWhiteSpace();

    return true;
  }

  int minus = name.find('-');
  if (minus >= 0)
  {
    artist = name.left(minus).simplifyWhiteSpace();
    song = name.right(name.length()-minus-1).simplifyWhiteSpace();

    return true;
  }

  return false;
}

inline QString getArtist(QString filename)
{
  QString song, artist;
  if( getSongArtist(filename, song, artist ) )
  {
    return artist;
  }
  return "";
}

inline QString getTitle(QString filename)
{
  QString song, artist;
  if( getSongArtist(filename, song, artist ) )
  {
    return song;
  }
  return "";
}

#endif
